@@ -23,7 +23,7 @@ DETEKT_VERSION = "1.1.1"
 
 
 def run_detekt(files):
-    detekt_exec = ROOT.parent / "detekt-cli-{}-all.jar".format(DETEKT_VERSION)
+    detekt_exec = ROOT.parent / f"detekt-cli-{DETEKT_VERSION}-all.jar"
     # We want to make sure this runs on CI, but it's not required
     # for local development
     if detekt_exec.is_file() or "CI" in os.environ:
@@ -327,3 +327,29 @@ def test_gecko_datapoints(tmpdir):
             assert "HistogramMetricBase" not in content
 
     run_linters(tmpdir.glob("*.kt"))
+
+
+def test_event_extra_keys_in_correct_order(tmpdir):
+    """
+    Assert that the extra keys appear in the parameter and the enumeration in
+    the same order.
+
+    https://bugzilla.mozilla.org/show_bug.cgi?id=1648768
+    """
+
+    tmpdir = Path(str(tmpdir))
+
+    translate.translate(
+        ROOT / "data" / "event_key_ordering.yaml",
+        "kotlin",
+        tmpdir,
+        {"namespace": "Foo"},
+    )
+
+    assert set(x.name for x in tmpdir.iterdir()) == set(["Event.kt"])
+
+    with (tmpdir / "Event.kt").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        content = " ".join(content.split())
+        assert "exampleKeys { alice, bob, charlie }" in content
+        assert 'allowedExtraKeys = listOf("alice", "bob", "charlie")' in content
